.. _CLI:

Steamship CLI
-------------

To install the Steamship CLI, run:

.. code-block:: bash

   npm install -g @steamship/cli

This will provide access to the ``ship`` command in your shell. It can be used for login, project creation, and account operations.

Try it out by typing ``ship login`` or `view the documentation here <https://github.com/steamship-core/steamship-cli/blob/main/README.md>`_

